abacusai.page_data — AbacusAI documentation

# `abacusai.page_data`

## Module Contents

### Classes

`PageData` | Data extracted from a docstore page.

class abacusai.page_data.PageData(client, docId=None, page=None, pageCount=None, pageText=None, pageTokenStartOffset=None, tokenCount=None, tokens=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Data extracted from a docstore page.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - docId (str) – Unique Docstore string identifier for the document.

    - page (int) – The page number. Starts from 0.

    - pageCount (int) – The total number of pages in document.

    - pageText (str) – The text extracted from the page.

    - pageTokenStartOffset (int) – The offset of the first token in the page.

    - tokenCount (int) – The number of tokens in the page.

    - tokens (list) – The tokens in the page.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict